#!/usr/bin/env python

"""
A program which generates LinkOut XML files from a list of genes.

--------

Copyright (C) 2011 Ian Donaldson <ian.donaldson@biotek.uio.no>
Original author: Paul Boddie <paul.boddie@biotek.uio.no>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from os.path import join

def get_template(filename):
    f = open(join("templates", filename))
    try:
        return f.read()
    finally:
        f.close()

if __name__ == "__main__":
    import sys

    try:
        genes_filename = sys.argv[1]
        linkout_resources_filename = sys.argv[2]
        linkout_provider_filename = sys.argv[3]
        providerid = sys.argv[4]
    except IndexError:
        sys.stdout.write("%s <genes-file> <resources-file> <provider-file> <provider-identifier>\n" % sys.argv[0])
        sys.exit(1)

    header = get_template("resources_header.xml")
    footer = get_template("resources_footer.xml")
    link = get_template("resources_link.xml")

    f = open(genes_filename)
    out = open(linkout_resources_filename, "w")
    try:
        out.write(header % locals())
        for i, line in enumerate(f.xreadlines()):
            geneid = line.strip()
            linkid = i + 1
            out.write(link % locals())
        out.write(footer % locals())
    finally:
        out.close()
        f.close()

    provider = get_template("providerinfo.xml")
    out = open(linkout_provider_filename, "w")
    try:
        out.write(provider % locals())
    finally:
        out.close()

# vim: tabstop=4 expandtab shiftwidth=4
